@@ -48,11 +48,13 @@ from schooltool.app.interfaces import ISchoolToolApplication
 from schooltool.app.browser import app
 from schooltool.app.membership import URIGroup, URIMembership
 from schooltool.intervention import InterventionGettext as _
+from schooltool.common import format_message
 from schooltool.common.inlinept import InheritTemplate
 from schooltool.common.inlinept import InlineViewPageTemplate
 from schooltool.contact.interfaces import IContact
 from schooltool.course.interfaces import ISection, IInstructor
-from schooltool.email.interfaces import IEmailUtility
+from schooltool.email.interfaces import IEmailUtility, IEmailContainer
+from schooltool.email.mail import status_messages
 from schooltool.intervention import intervention, sendmail, catalog
 from schooltool.intervention import interfaces
 from schooltool.person.interfaces import IPerson
@@ -92,11 +94,11 @@ class FlourishInterventionNavViewlet(flourish.page.LinkViewlet):
         return IPerson(self.request.principal, None)
 
     @property
-    def title(self):
+    def enabled(self):
         person = self.person
         if person is None or queryUtility(IDateManager).current_term is None:
-            return ''
-        return _('Intervention')
+            return False
+        return True
 
     @property
     def url(self):
@@ -586,7 +588,37 @@ class InterventionStudentView(object):
         self.allStatusMessagesURL = interventionURL + '/messages/allStatusMessages.html'
 
 
-class FlourishInterventionStudentView(flourish.page.Page):
+class EmailMixin(object):
+    """Mixin class for getting messages for modal email sent notification."""
+
+    @property
+    def email(self):
+        fail_message = _('The email could not be delivered to all recipients.')
+        email_info = self.request.get('email')
+        if email_info:
+            messages = []
+            email_container = IEmailContainer(ISchoolToolApplication(None))
+            for info in email_info.split('|'):
+                if '@' in info:
+                    messages.append(translate(
+                        format_message(
+                            _('An email message was sent to: ${to_addresses}'),
+                            mapping={'to_addresses': info}),
+                        context=self.request))
+                else:
+                    messages.append(fail_message)
+                    email = email_container.get(info, None)
+                    if email is not None:
+                        messages.append(translate(
+                            format_message(
+                                status_messages[email.status_code],
+                                mapping=email.status_parameters),
+                            context=self.request))
+            return messages
+        return ''
+
+
+class FlourishInterventionStudentView(EmailMixin, flourish.page.Page):
     """Flourish View for managing a student's intervention."""
 
     @property
@@ -907,7 +939,7 @@ class SectionInterventionsView(object):
         return sorted(rows, key=lambda row: row['sortName'])
 
 
-class FlourishSectionInterventionsView(flourish.page.Page,
+class FlourishSectionInterventionsView(EmailMixin, flourish.page.Page,
                                        SectionInterventionsView):
     """Flourish tabbed section view showing links for adding or editing
        intervention data."""
@@ -1024,6 +1056,15 @@ class InterventionMessageAddView(app.BaseAddView):
         sender = IContact(self.request.principal._person)
         return self._factory(sender, *args)
 
+    def add(self, message):
+        """Add message to the student's messages."""
+        context = self.context.context
+        chooser = INameChooser(context)
+        name = chooser.chooseName('', message)
+        context[name] = message
+        email = sendmail.sendInterventionMessageEmail(message)
+        return message
+
     def nextURL(self):
         """If section is in the context heirachcy, return to the section
            interventions view.  Otherwise return to the student's intervention
@@ -1040,7 +1081,8 @@ class IMessageAddForm(interfaces.IInterventionMessage):
     email = Bool(
         title=_(u"Email"),
         description=_(u"You can automatically send an email of this message."),
-        required=False)
+        required=False,
+        default=True)
 
 
 class FlourishInterventionMessageAddView(flourish.form.AddForm):
@@ -1073,8 +1115,16 @@ class FlourishInterventionMessageAddView(flourish.form.AddForm):
             return
         obj = self.createAndAdd(data)
         if obj is not None:
-            # mark only as finished if we get the new object
-            self._finishedAdd = True
+            if data.get('email'):
+                email = sendmail.sendInterventionMessageEmail(obj)
+                if email.status_code is None:
+                    info = ', '.join(email.to_addresses)
+                else:
+                    info = email.__name__
+                url = '%s?email=%s' % (self.nextURL(), info)
+                self.request.response.redirect(url)
+            else:
+                self._finishedAdd = True
 
     @button.buttonAndHandler(_("Cancel"))
     def handle_cancel_action(self, action):
@@ -1117,6 +1167,15 @@ class InterventionStatusMessageAddView(app.BaseAddView):
         kw['status_change'] = True
         return self._factory(sender, *args, **kw)
 
+    def add(self, message):
+        """Add message to the student's messages."""
+        context = self.context.context
+        chooser = INameChooser(context)
+        name = chooser.chooseName('', message)
+        context[name] = message
+        email = sendmail.sendInterventionMessageEmail(message)
+        return message
+
     def nextURL(self):
         """If section is in the context heirachcy, return to the section
            interventions view.  Otherwise return to the student's intervention
@@ -1261,6 +1320,15 @@ class InterventionGoalAddView(app.BaseAddView):
         kw['creator'] = creator
         return self._factory(*args, **kw)
 
+    def add(self, goal):
+        """Add goal to the student's goals."""
+        context = self.context.context
+        chooser = INameChooser(context)
+        name = chooser.chooseName('', goal)
+        context[name] = goal
+        emails = sendmail.sendInterventionGoalAddEmail(goal)
+        return goal
+
     def nextURL(self):
         interventionStudent = self.context.context.__parent__
         return absoluteURL(interventionStudent, self.request)
@@ -1275,7 +1343,8 @@ class IGoalAddForm(interfaces.IInterventionGoal):
     email = Bool(
         title=_(u"Email"),
         description=_(u"You can automatically send an email of this goal."),
-        required=False)
+        required=False,
+        default=True)
 
 
 class SimpleFormAdapter(object):
@@ -1322,8 +1391,18 @@ class FlourishInterventionGoalAddView(flourish.form.AddForm):
             return
         obj = self.createAndAdd(data)
         if obj is not None:
-            # mark only as finished if we get the new object
-            self._finishedAdd = True
+            if data.get('email'):
+                info = []
+                emails = sendmail.sendInterventionGoalAddEmail(obj)
+                for email in emails:
+                    if email.status_code is None:
+                        info.append(', '.join(email.to_addresses))
+                    else:
+                        info.append(email.__name__)
+                url = '%s?email=%s' % (self.nextURL(), '|'.join(info))
+                self.request.response.redirect(url)
+            else:
+                self._finishedAdd = True
 
     @button.buttonAndHandler(_("Cancel"))
     def handle_cancel_action(self, action):
