@@ -174,7 +174,7 @@ class IInterventionGoal(IContained):
         )
 
     follow_up_notes = Text(
-        title=_("Follow-up notes"),
+        title=_("Follow up notes"),
         required=False
         )
 
